# Introduction

The *steinbock* framework can be used as a regular Python package:

    import steinbock

Please refer to the *steinbock* API documentation for further details.

!!! danger "Work in progress"
    The *steinbock* API documentation is work in progress.
